import os
import re

def process_folder(input_folder, output_folder):
    if not os.path.exists(output_folder):
        os.makedirs(output_folder)
        print(f"Created output folder: {output_folder}")

    convexshapes_files = [filename for filename in os.listdir(input_folder) if filename.endswith(".convexshapes")]
    total_files = len(convexshapes_files)

    if total_files == 0:
        print("No .convexshapes files found in the input folder.")
        return

    processed_files = 0
    for filename in convexshapes_files:
        input_file = os.path.join(input_folder, filename)
        output_prefix = os.path.splitext(filename)[0]
        try:
            process_file(input_file, output_folder, output_prefix)
            processed_files += 1
            print(f"Processed file: {filename}")
        except Exception as e:
            print(f"Error processing file: {filename}")
            print(f"Error message: {str(e)}")

    print(f"Total files processed: {processed_files}/{total_files}")

def process_file(input_file, output_folder, output_prefix):
    component_template = '''
embedded_components {{
\tid: "{go_id}_{index}"
\ttype: "collisionobject"
\tdata: "collision_shape: \\"{rel_path}{output_prefix}_poly{index}.convexshape\\"\\n"
\t"type: COLLISION_OBJECT_TYPE_{go_type}\\n"
\t"mass: {go_mass}\\n"
\t"friction: {go_friction}\\n"
\t"restitution: {go_restitution}\\n"
\t"group: \\"{go_group}\\"\\n"
\t"mask: \\"{go_mask}\\"\\n"
\t"linear_damping: {go_linear_damping}\\n"
\t"angular_damping: {go_angular_damping}\\n"
\t"locked_rotation: {go_locked_rotation}\\n"
\t""
\tposition {{
\t\tx: 0.0
\t\ty: 0.0
\t\tz: 0.0
\t}}
\trotation {{
\t\tx: 0.0
\t\ty: 0.0
\t\tz: 0.0
\t\tw: 1.0
\t}}
}}
'''

    go_id = os.path.splitext(os.path.basename(input_file))[0]
    go_type = "STATIC"
    go_mass = 0.0
    go_friction = 0.1
    go_restitution = 0.5
    go_linear_damping = 0.0
    go_angular_damping = 0.0
    go_locked_rotation = "false"
    go_group = "default"
    go_mask = "default"

    index = 1
    data = ""
    go_content = ""

    with open(input_file, "r") as file:
        lines = file.readlines()

    for line in lines:
        line = line.strip()

        if line.startswith("shape_type: TYPE_HULL"):
            if data != "":
                output_file = os.path.join(output_folder, f"{output_prefix}_poly{index}.convexshape")
                with open(output_file, "w") as file:
                    file.write(data)

                rel_path = "/"

                go_content += component_template.format(
                    go_id=go_id,
                    index=index,
                    rel_path=rel_path,
                    output_prefix=output_prefix,
                    go_type=go_type,
                    go_mass=go_mass,
                    go_friction=go_friction,
                    go_restitution=go_restitution,
                    go_linear_damping=go_linear_damping,
                    go_angular_damping=go_angular_damping,
                    go_locked_rotation=go_locked_rotation,
                    go_group=go_group,
                    go_mask=go_mask
                )

                data = ""
                index += 1

            data += line + "\n"
        elif line.startswith("data: "):
            data += line + "\n"

    if data != "":
        output_file = os.path.join(output_folder, f"{output_prefix}_poly{index}.convexshape")
        with open(output_file, "w") as file:
            file.write(data)

        rel_path = "/"

        go_content += component_template.format(
            go_id=go_id,
            index=index,
            rel_path=rel_path,
            output_prefix=output_prefix,
            go_type=go_type,
            go_mass=go_mass,
            go_friction=go_friction,
            go_restitution=go_restitution,
            go_linear_damping=go_linear_damping,
            go_angular_damping=go_angular_damping,
            go_locked_rotation=go_locked_rotation,
            go_group=go_group,
            go_mask=go_mask
        )

    output_file = os.path.join(output_folder, f"{output_prefix}.go")
    with open(output_file, "w") as file:
        file.write(go_content)

# Usage
input_folder = "input"
output_folder = "output"
process_folder(input_folder, output_folder)